@@ -27,6 +27,18 @@ InputConv::InputConv() {
 	specialKeys.insert(Qt::Key_F10, "F10");
 	specialKeys.insert(Qt::Key_F11, "F11");
 	specialKeys.insert(Qt::Key_F12, "F12");
+	specialKeys.insert(Qt::Key_F13, "F13");
+	specialKeys.insert(Qt::Key_F14, "F14");
+	specialKeys.insert(Qt::Key_F15, "F15");
+	specialKeys.insert(Qt::Key_F16, "F16");
+	specialKeys.insert(Qt::Key_F17, "F17");
+	specialKeys.insert(Qt::Key_F18, "F18");
+	specialKeys.insert(Qt::Key_F19, "F19");
+	specialKeys.insert(Qt::Key_F20, "F20");
+	specialKeys.insert(Qt::Key_F21, "F21");
+	specialKeys.insert(Qt::Key_F22, "F22");
+	specialKeys.insert(Qt::Key_F23, "F23");
+	specialKeys.insert(Qt::Key_F24, "F24");
 
 	specialKeys.insert(Qt::Key_Backspace, "BS");
 	specialKeys.insert(Qt::Key_Delete, "Del");
@@ -79,9 +91,6 @@ QString InputConv::modPrefix(Qt::KeyboardModifiers mod)
 	   ) {
 		modprefix += "A-";
 	}
-    if ( mod & Qt::KeypadModifier ) {
-        modprefix += "k";
-    } 
 
 	return modprefix;
 }
@@ -153,6 +162,51 @@ QString InputConv::convertMouse(Qt::MouseButton bt, QEvent::Type type, Qt::Keybo
  */
 QString InputConv::convertKey(const QString& text, int k, Qt::KeyboardModifiers mod)
 {
+    if ( mod & Qt::KeypadModifier ) {
+		switch (k) {
+		case Qt::Key_Home:
+			return QString("<%1kHome>").arg(modPrefix(mod));
+		case Qt::Key_End:
+			return QString("<%1kEnd>").arg(modPrefix(mod));
+		case Qt::Key_PageUp:
+			return QString("<%1kPageUp>").arg(modPrefix(mod));
+		case Qt::Key_PageDown:
+			return QString("<%1kPageDown>").arg(modPrefix(mod));
+		case Qt::Key_Plus:
+			return QString("<%1kPlus>").arg(modPrefix(mod));
+		case Qt::Key_Minus:
+			return QString("<%1kMinus>").arg(modPrefix(mod));
+		case Qt::Key_multiply:
+			return QString("<%1kMultiply>").arg(modPrefix(mod));
+		case Qt::Key_division:
+			return QString("<%1kDivide>").arg(modPrefix(mod));
+		case Qt::Key_Enter:
+			return QString("<%1kEnter>").arg(modPrefix(mod));
+		case Qt::Key_Period:
+			return QString("<%1kPoint>").arg(modPrefix(mod));
+		case Qt::Key_0:
+			return QString("<%1k0>").arg(modPrefix(mod));
+		case Qt::Key_1:
+			return QString("<%1k1>").arg(modPrefix(mod));
+		case Qt::Key_2:
+			return QString("<%1k2>").arg(modPrefix(mod));
+		case Qt::Key_3:
+			return QString("<%1k3>").arg(modPrefix(mod));
+		case Qt::Key_4:
+			return QString("<%1k4>").arg(modPrefix(mod));
+		case Qt::Key_5:
+			return QString("<%1k5>").arg(modPrefix(mod));
+		case Qt::Key_6:
+			return QString("<%1k6>").arg(modPrefix(mod));
+		case Qt::Key_7:
+			return QString("<%1k7>").arg(modPrefix(mod));
+		case Qt::Key_8:
+			return QString("<%1k8>").arg(modPrefix(mod));
+		case Qt::Key_9:
+			return QString("<%1k9>").arg(modPrefix(mod));
+		}
+    }
+
 	if (specialKeys.contains(k)) {
 		return QString("<%1%2>").arg(modPrefix(mod)).arg(specialKeys.value(k));
 	}
@@ -184,7 +238,7 @@ QString InputConv::convertKey(const QString& text, int k, Qt::KeyboardModifiers
 	}
 
 	// Remove SHIFT
-	if (c.unicode() < 0x100 && !c.isLetterOrNumber() && c.isPrint()) {
+    if (c.unicode() >= 0x80 || (!c.isLetterOrNumber() && c.isPrint())) {
 		mod &= ~ShiftModifier;
 	}
 
