@@ -10,6 +10,8 @@ MainWindow::MainWindow(NeovimConnector *c, QWidget *parent)
 {
 	m_errorWidget = new ErrorWidget();
 	m_stack.addWidget(m_errorWidget);
+	connect(m_errorWidget, &ErrorWidget::reconnectNeovim,
+			this, &MainWindow::reconnectNeovim);
 	setCentralWidget(&m_stack);
 
 	init(c);
@@ -39,12 +41,12 @@ void MainWindow::init(NeovimConnector *c)
 			this, &MainWindow::neovimMaximized);
 	connect(m_shell, &Shell::neovimFullScreen,
 			this, &MainWindow::neovimFullScreen);
+	connect(m_shell, &Shell::neovimGuiCloseRequest,
+			this, &MainWindow::neovimGuiCloseRequest);
 	connect(m_nvim, &NeovimConnector::processExited,
 			this, &MainWindow::neovimExited);
 	connect(m_nvim, &NeovimConnector::error,
 			this, &MainWindow::neovimError);
-	connect(m_errorWidget, &ErrorWidget::reconnectNeovim,
-			this, &MainWindow::reconnectNeovim);
 	m_shell->setFocus(Qt::OtherFocusReason);
 
 	if (m_nvim->errorCause()) {
@@ -121,6 +123,11 @@ void MainWindow::neovimFullScreen(bool set)
 	}
 }
 
+void MainWindow::neovimGuiCloseRequest()
+{
+	QMainWindow::close();
+}
+
 void MainWindow::reconnectNeovim()
 {
 	if (m_nvim->canReconnect()) {
