@@ -21,6 +21,7 @@ Shell::Shell(NeovimConnector *nvim, QWidget *parent)
 	m_hg_foreground(Qt::black), m_hg_background(Qt::white), m_hg_special(QColor()),
 	m_cursor_color(Qt::white), m_cursor_pos(0,0), m_insertMode(false),
 	m_resizing(false),
+	m_mouse_wheel_delta_fraction(0, 0),
 	m_neovimBusy(false)
 {
 	setAttribute(Qt::WA_KeyCompression, false);
@@ -666,9 +667,29 @@ void Shell::mouseMoveEvent(QMouseEvent *ev)
 
 void Shell::wheelEvent(QWheelEvent *ev)
 {
+#ifdef Q_OS_MAC
+	// For some reason <ScrollWheel*> scrolls multiple lines at once
+	// we have to account for it, to make sure that pixelDelta() is used correctly.
+	const int scroll_columns = 6;
+	const int scroll_rows = 3;
+	// Minimal scroll step
+	int scroll_step_x = cellSize().width() * scroll_columns;
+	int scroll_step_y = cellSize().height() * scroll_rows;
+	// Total scroll delta considering previous events
+	QPoint total_delta = m_mouse_wheel_delta_fraction + ev->pixelDelta();
+	// Delta rounded to a minimal scroll step
+	QPoint cell_delta(total_delta.x() / scroll_step_x, total_delta.y() / scroll_step_y);
+	// Save remainder for future events
+	m_mouse_wheel_delta_fraction = total_delta - QPoint(cell_delta.x() * scroll_step_x, cell_delta.y() * scroll_step_y);
+
+	int horiz = cell_delta.x();
+	int vert = cell_delta.y();
+#else
 	int horiz, vert;
 	horiz = ev->angleDelta().x();
 	vert = ev->angleDelta().y();
+#endif
+
 	if (horiz == 0 && vert == 0) {
 		return;
 	}
@@ -686,7 +707,7 @@ void Shell::wheelEvent(QWheelEvent *ev)
 	if (horiz != 0) {
 		inp += QString("<%1ScrollWheel%2><%3,%4>")
 			.arg(Input.modPrefix(ev->modifiers()))
-			.arg(horiz > 0 ? "Right" : "Left")
+			.arg(horiz > 0 ? "Left" : "Right")
 			.arg(pos.x()).arg(pos.y());
 	}
 	m_nvim->neovimObject()->vim_input(inp.toLatin1());
@@ -805,13 +826,14 @@ void Shell::closeEvent(QCloseEvent *ev)
 
 void Shell::focusInEvent(QFocusEvent *ev)
 {
-	m_nvim->neovimObject()->vim_input("<FocusGained>");
+	// See neovim-qt/issues/329 the FocusGained key no longer exists, use autocmd instead
+	m_nvim->neovimObject()->vim_command("if exists('#FocusGained') | doautocmd FocusGained | endif");
 	QWidget::focusInEvent(ev);
 }
 
 void Shell::focusOutEvent(QFocusEvent *ev)
 {
-	m_nvim->neovimObject()->vim_input("<FocusLost>");
+	m_nvim->neovimObject()->vim_command("if exists('#FocusLost') | doautocmd FocusLost | endif");
 	QWidget::focusOutEvent(ev);
 }
 
