@@ -22,7 +22,6 @@ class NeovimConnector: public QObject
 	 * @see neovimObject
 	 */
 	Q_PROPERTY(bool ready READ isReady NOTIFY ready)
-	Q_ENUMS(NeovimError)
 public:
 	enum NeovimError {
 		NoError=0,
@@ -37,6 +36,11 @@ public:
 		MsgpackError,
 		RuntimeMsgpackError,
 	};
+#ifdef Q_ENUM
+	Q_ENUM(NeovimError)
+#else
+	Q_ENUMS(NeovimError)
+#endif
 
 	/** Underlying connection used to read Neovim */
         enum NeovimConnectionType {
@@ -71,6 +75,8 @@ public:
 	QString decode(const QByteArray&);
 	QByteArray encode(const QString&);
 	NeovimConnectionType connectionType();
+	/** Some requests for metadata and ui attachment enforce a timeout in ms */
+	void setRequestTimeout(int);
 
 signals:
 	/** Emitted when Neovim is ready @see ready */
@@ -107,6 +113,7 @@ private:
 	QString m_connSocket, m_connHost;
 	int m_connPort;
 	bool m_ready;
+	int m_timeout;
 };
 } // namespace NeovimQt
 Q_DECLARE_METATYPE(NeovimQt::NeovimConnector::NeovimError)
